Optionally install software for running production server, see :ref:`server`,
:ref:`database-setup`, :ref:`celery`. Depending on size of your installation
you might want to run these components on dedicated servers.

The local installation instructions:
